aboutsummaryrefslogtreecommitdiff
path: root/src/libfetchers
diff options
context:
space:
mode:
Diffstat (limited to 'src/libfetchers')
-rw-r--r--src/libfetchers/fetchers.cc10
1 files changed, 6 insertions, 4 deletions
diff --git a/src/libfetchers/fetchers.cc b/src/libfetchers/fetchers.cc
index 210912cb6..e09513d8f 100644
--- a/src/libfetchers/fetchers.cc
+++ b/src/libfetchers/fetchers.cc
@@ -133,10 +133,12 @@ std::pair<Tree, Input> Input::fetch(ref<Store> store) const
}
auto [storePath, input] = [&]() -> std::pair<StorePath, Input> {
- // *sighs*, we print the base URL, rather than the full URL because the Nixpkgs
- // fileset lib tests assume that fetching shallow and non-shallow prints exactly the
- // same stderr...
- printInfo("fetching %s input '%s'", this->getType(), this->toURL().base);
+ // *sighs*, we print the URL without query params, rather than the full URL
+ // because the Nixpkgs fileset lib tests assume that fetching shallow and
+ // non-shallow prints exactly the same stderr...
+ ParsedURL withoutParams = this->toURL();
+ withoutParams.query.clear();
+ printInfo("fetching %s input '%s'", this->getType(), withoutParams.to_string());
try {
return scheme->fetch(store, *this);
} catch (Error & e) {